{% load i18n %}

<div class="module" id="recent-actions-module">
    <h2>{% trans 'Recent Actions' %}</h2>
    <h3>{% trans 'My Actions' %}</h3>
    {% load log %}
    {% get_admin_log 10 as admin_log for_user user %}
    {% if not admin_log %}
    <p>{% trans 'None available' %}</p>
    {% else %}
    <ul class="actionlist" style="margin:0;">
        {% for entry in admin_log %}
        <li style="list-style-type:none;"
            class="{% if entry.is_addition %}addlink{% endif %}{% if entry.is_change %}changelink{% endif %}{% if entry.is_deletion %}deletelink{% endif %}">
            {% if not entry.is_deletion %}<a href="{{ entry.get_admin_url }}">{% endif %}{{ entry.object_repr }}{% if
            not entry.is_deletion %}</a>{% endif %}<br/><span class="mini quiet">{% filter capfirst %}{% trans entry.content_type.name %}{% endfilter %}</span>
        </li>
        {% endfor %}
    </ul>
    {% endif %}
</div>

