{% load shuyucms_tags %}
{% ifinstalled shuyucms.accounts %}
<div class="panel panel-default user-panel">
    <div class="panel-body">
        {% include "accounts/includes/user_panel.html" %}
    </div>
</div>
{% endifinstalled %}
