{% load i18n %}

{% if form.non_field_errors or form.errors %}
<div class="form-errors">
    {% for error in form.non_field_errors %}
    <div class="alert alert-danger non-field-error">{{ error }}</div>
    {% empty %}
    <div class="alert alert-danger field-error">{% trans "Please correct the errors below." %}</div>
    {% endfor %}
</div>
{% endif %}
