/*=====================================
                HEADER
=======================================*/
#header {
    height: 40px;
}
#header * {
    font-size: 13px;
    font-weight: normal;
}
.admin-title, #user-tools {
    margin: 5px 10px 5px 2px;
}
h1 {
    font-size: 24px;
    padding: 10px 0 20px;
    z-index: 0;
    /* Grappelli defines a zindex that places h1s on top
                      of date-picker widgets, making them unclickable. */
}
.object-tools {
    margin: -50px 0 -35px;
}
.admin-title {
    background: #555;
    font-weight: bold !important;
    text-transform: uppercase;
    width: 181px;
    padding: 13px 20px;
    margin: 0;
    font-size: 12px !important;
}
.action-counter {
    padding: 5px 0 0 2px;
}
/*=====================================
            LOGIN ELEMENTS
=======================================*/
#login-form {
    margin-top: 100px;
}
.login .submit-row, .login #content-main {
    width: 450px;
}
.login .form-row label {
    width: 160px;
}
#extra-login-fields .required {
    margin-top: 1px;
}
input.interface {
    margin: 0 5px 0 0;
    vertical-align: middle;
}
label.interface {
    display: inline !important;
    float: none !important;
    vertical-align: middle;
    cursor: pointer;
}
#forgot-password {
    margin-top: 30px;
    text-align: center;
}
.submit-row input {
    margin-left: 8px;
}
.login .errornote {
    width: 101%;
    margin-left: -15px !important;
    padding-left: 15px;
    top: 40px !important;
}
.login .form-row {
    overflow: visible;
    height: 25px;
}
/*=====================================
            NAVIGATION
=======================================*/
.admin-title {
    cursor: pointer;
    font-size: 15px !important;
}
#user-tools, #header form {
    float: right;
    position: relative;
}
#header form {
    margin: 7px 4px;
}
.add-row {
    display: none;
}
.breadcrumbs {
    display: none;
}
ul.messagelist {
    margin-left: 224px;
    top: 40px;
    z-index: 0;
}
.messagelist.full {
    margin-left: 17px;
}
.login .errornote, ul.messagelist li {
    font-size: 14px !important;
    font-weight: normal !important;
    padding: 10px 28px;
}
.login .errornote, ul.messagelist li.error {
    background: #BD362F;
    padding-left: 25px;
}
body.popup .breadcrumbs + ul.messagelist {
    top: -10px;
    margin-left: -10px;
    margin-right: -10px;
}
#side-panel {
    background-color: #3f3f3f;
    height: 100%;
    left: 0;
    position: fixed;
    top: 0;
    z-index: 2;
}
.dropdown-menu {
    border-right: 1px solid #222;
    float: left;
    height: 95%; /* Fallback height */
    height: -webkit-calc(100% - 40px); /* Safari 6.0 */
    height: calc(100% - 40px); /* Firefox, Chrome, IE9+ */
    margin-top: 40px;
    overflow-x: hidden;
    overflow-y: auto;
    width: 216px;
}
.dropdown-menu.hidden {
    margin-left: -207px;
}
.dropdown-menu > ul {
    border-bottom: 1px solid #555;
}
.dropdown-menu > ul > li {
    padding: 20px 17px;
    list-style-type: none;
    border-bottom: 1px solid #222;
    border-top: 1px solid #555;
}
.dropdown-menu > ul > li:first-child {
    border-top: 0;
}
.dropdown-menu-menu > li {
    padding: 15px 0 0 1px;
}
.dropdown-menu li a {
    font-size: 16px;
    padding-left: 8px;
}
.dropdown-menu li a:hover {
    color: #fff;
}
.dropdown-menu .selected,
.dropdown-menu-menu > li > a:hover {
    border-left: 10px solid #666;
    margin-left: -20px;
    padding-left: 18px;
}
.dropdown-menu li li a {
    font-size: 15px;
    color: #ccc;
    display: block;
}
.dropdown-menu form {
    display: none;
}
#side-panel-toggle {
    background-color: #eee;
    cursor: pointer;
    float: right;
    height: 100%;
    width: 7px;
}
#side-panel-toggle:hover,
#side-panel-toggle:focus {
    background-color: #ccc;
}
/*=====================================
        FIXED BOTTOM CONTROLS
=======================================*/
.change-form .submit-row {
    position: fixed;
    left: 216px;
    bottom: 0;
    right: 0;
    margin: 0;
    padding: 10px 20px;
    background: #e6e6e6;
    border-top: 1px solid #ccc;
    text-align: right;
}
.popup div.submit-row {
    left: 0;
}
.change-form .full .submit-row,
.full #settings-form .submit-row {
    left: 9px;
}
.submit-row input, .button, .submit-row a, .object-tools a {
    margin: 0 3px;
    padding: 7px 15px !important;
    font-size: 15px;
    height: auto !important;
}
fieldset.module {
    margin-bottom: 25px;
}
fieldset .field-box {
    margin: 0 150px 10px 0 !important;
}
.form-row label + p.datetime {
    margin-bottom: 5px;
}
.datetimeshortcuts a {
    margin: 5px;
}
form .aligned input + label + p.help {
    margin: 2px 0 0 152px !important;
}
.form-row .nbsp {
    display: none;
}
.help b {
    color: #666;
}
/*=====================================
        GENERAL STYLE TWEAKS
=======================================*/
/* CSS Animations (used for the sliding panel) */
.animated {
    transition: all 0.2s ease-in-out;
}
/* Some reasonable font sizes */
td, th, th a, label, .help, p.help {
    font-size: 13px !important;
}
/* shuyucms.core.fields.MultiChoiceField */
.multicheckbox li {
    list-style-type: none;
    float: left;
    margin-right: 10px;
}
.multicheckbox li label {
    width: auto;
    font-weight: normal;
}
.multicheckbox input {
    margin: -1px 6px 0 0;
}
/* description / generate */
.gen_description textarea {
    margin-bottom: 10px;
}
#container {
    position: inherit;
}
#content {
    margin: 60px 10px 60px 235px;
    padding: 0 15px 0 15px;
}
.popup #content {
    margin-left: 0;
}
#content.full {
    margin-left: 22px;
}
#djDebugToolbarHandle {
    margin-top: 50px !important;
}
.inline-stacked ._order, div.dynamic-fields ._order {
    display: none;
}
.items .placeholder {
    display: block;
}
.keywords-field a {
    margin-right: 10px;
    float: left;
}
#settings-form .module {
    width: 80%;
}
#settings-form .help {
    margin-right: 10px;
}
#settings-form .charfield {
    width: 60% !important;
}
#settings-form .integerfield {
    width: 30px !important;
}
#changelist .send_tweet_container {
    display: none;
}
.send_tweet_container {
    display: inline;
}
.send_tweet_container * {
    margin-right: -5px !important;
    vertical-align: top;
    top: 5px !important;
    position: relative;
}
