/* dashboard */

#content-related.dashboard1 {
    margin: 0 10px 0 -38em;
}
#content-related.dashboard2 {
    margin-left: -19em;
}
/* global */

#side-panel {
    left: auto;
    right: 0;
}
.dropdown-menu {
    float: right;
}
#side-panel-toggle {
    float: left;
}
.dropdown-menu.hidden {
    margin-left: auto;
    margin-right: -207px;
}
#content {
    margin: 60px 235px 60px 10px !important;
}
#content.full {
    margin-left: auto;
    margin-right: 22px !important;
}
ul.messagelist {
    margin-left: 0;
    margin-right: 224px;
}
.messagelist.full {
    margin-left: 0;
    margin-right: 17px;
}
.dropdown-menu .selected, .dropdown-menu-menu > li > a:hover {
    border-left: none;
    margin-left: 0;
    padding-left: 0;
    border-right: 10px solid #666;
    margin-right: -20px;
    padding-right: 10px;
}
.dropdown-menu form {
    float: left;
    margin: 3px 0 0 22px;
}
.cloned li {
    font-size: 14px;
    padding: 15px 20px 15px 25px;
}
.submit-row input {
    margin-left: 0;
    margin-right: 8px;
}
.help {
    clear: right;
}
#settings-form .help {
    margin-left: 10px;
    margin-right: 230px;
}
.multicheckbox li {
    float: right;
    margin-right: 0;
    margin-left: 10px;
}
.multicheckbox li label {
    white-space: nowrap; /* workaround for chrome to prevent line breaks */
}
.multicheckbox input {
    margin: -1px 0 0 6px;
}
fieldset .field-box {
    margin-right: 0 !important;
    margin-left: 150px !important;
}
.change-form div.submit-row {
    left: 0;
    right: 216px;
    text-align: left;
}
.change-form .full .submit-row, .full #settings-form .submit-row {
    left: 0;
    right: 9px;
}
input.interface {
    margin: 0 0 0 5px;
}
form .aligned input + label + p.help {
    margin: 2px 152px 0 0 !important;
}
/* page tree */

#tree div {
    float: right;
}
#tree .tree-toggle, #tree .changelink {
    float: right;
}
#tree .changelink {
    background-position: 100% 5px;
}
#tree a .icon {
    float: right;
    margin: 0 4px 0 8px;
}
#tree a {
    float: left;
}
#tree .tree-toggle, #tree .changelink {
    font-size: 15px;
    line-height: 18px;
}
.ordering {
    float: left;
    margin-left: 0;
    margin-right: 10px;
}
.grappelli-delete {
    margin: 4px 10px 0 4px;
}
.addlist {
    float: left;
}
#addlist-primary {
    float: right;
}
#tree ol ol {
    padding-left: 0;
    padding-right: 40px;
}
/* settings */

#settings-form label {
    float: right;
}
#settings-form p input {
    float: right;
    margin: 2px 0 5px 10px;
}
/* in-line */

.mezz-fb-thumbnail {
    margin-right: 15px !important;
}
