{% extends "base.html" %}

{% load i18n %}

{% block meta_title %}
{% trans "Error" %}
{% endblock %}

{% block title %}
{% trans "Error" %}
{% endblock %}

{% block main %}
<div class="panel panel-danger">
    <div class="panel-heading"><h3 class="panel-title">{% trans "Error" %}</h3></div>
    <div class="panel-body">{% trans "Sorry, an error occurred." %}</div>
</div>
{% endblock %}
