#quick-blog input, textarea {
    width: 98%;
}
#quick-blog label {
    white-space: nowrap;
    width: auto;
}
#quick-blog th {
    width: auto;
}
.default {
    width: auto !important;
}
.module {
    margin-bottom: 10px !important;
}
.module ul {
    list-style-type: none !important;
    margin-left: 0;
}
.mini {
    font-size: .9em;
}
.dashboard #content {
    width: 40%;
}
.dashboard #content-main .module {
    background-color: #fff;
}
#content-related.dashboard1 {
    margin: 0 -100.2% 0 2%;
    width: 48%;
}
#content-related.dashboard2 {
    margin-right: -50%;
    width: 48%;
}
.dashboard #recent-index-head {
    width: 200%;
    float: left;
}
.dashboard #recent-index-head ul {
    background-color: #fff;
    float: left;
    width: 100%;
}
.dashboard #recent-index-head ul li {
    display: block;
    float: left;
    width: 15%;
    padding: 25px 22px;
    font-size: 15px;
}
.dashboard #sys-info {
    float: left;
    width: 100%;
    color: #666;
}
.dashboard #sys-info table {
    float: left;
    width: 100%;
    background-color: #fff;
}
.dashboard #sys-info table td {
    line-height: 20px;
    white-space: normal;
}
.dashboard #sys-info a {
    display: inline;
}
.dashboard #recent-index-head ul li a {
    color: #309bbf;
}
#comments-module ul {
    margin: 0;
}
#comments-module li {
    padding: 10px;
    list-style-type: none;
    margin: 0;
}
#comments-module span ul, #comments-module span li, #comments-module span p {
    margin: 0;
    padding: 0;
    border: 0
}
#comments-module img {
    vertical-align: middle;
    padding-right: 4px;
    float: left;
    max-width: 220px;
    height: auto
}
#comments-module span {
    display: block;
}
#comments-module p {
    padding: 3px 0;
    border-bottom: 1px solid #ddd;
    border-top: 0;
    font-size: 80%;
    margin-top: 4px;
    clear: both;
    font-style: normal;
}
#comments-module p a {
    font-style: normal;
}
