{% load i18n %}
<div class="dynamic-inline">
    {% include "admin/edit_inline/stacked.html" %}
    <p class="add-another"
       style="margin:10px; font-weight:bold; text-align:right;">
        <a href="#">{% trans "Add another" %}</a></p>
</div>
