{% load i18n future %}

{# Edit form #}
<form style="display:none;" class="editable-form" method="post"
      action="{% url " edit" %}" id="{{ editable_form.uuid }}"
{% if editable_form.is_multipart %} enctype="multipart/form-data"{% endif %}>
{% csrf_token %}
{% for field in editable_form %}
<p{% if field.is_hidden %} style="display:none;"{% endif %}>
{{ field.label_tag }}<br/>{{ field }}{{ field.errors }}
{% if field.help_text %}
<span class="helptext">{{ field.help_text }}</span>
{% endif %}
</p>
{% endfor %}
<input type="submit" value="{% trans " Save" %}" class="btn btn-primary btn-lg">
<input type="button" value="{% trans " Cancel" %}" class="btn btn-default btn-lg">
</form>

{# Original content wrapped in span #}
<div class="editable-original">{{ original }}</div>

{# Edit link #}
<a style="visibility:hidden;" class="editable-link" href="#"
   rel="#{{ editable_form.uuid }}">{% trans "Edit" %}</a>

{# Edit highlight #}
<div style="visibility:hidden;" class="editable-highlight"></div>
