{% load i18n future staticfiles %}

{% if has_site_permission %}
<link rel="stylesheet" href="{% static " shuyucms/css/editable.css" %}">
{{ richtext_media|safe }}
<script>
    {%
        url
        "fb_browse" as fb_browse_url %
    }
    {%
        url
        "static_proxy" as static_proxy_url %
    }
    {%
        get_current_language as LANGUAGE_CODE %
    }
    window.__syfilebrowser_url = '{{ fb_browse_url }}';
    window.__toolbar_html = '{{ toolbar|escapejs }}';
    window.__static_proxy = '{{ static_proxy_url }}';
    window.__language_code = '{{ LANGUAGE_CODE }}';
    window.__tinymce_css = '{% static "shuyucms/css/tinymce.css" %}';
</script>
<script src="{% static " shuyucms/js/jquery.tools.toolbox.expose.js" %}"></script>
<
script
src = "{% static "
shuyucms / js / jquery.tools.overlay.js
" %}" ></script>
<script src="{% static " shuyucms/js/jquery.form.js" %}"></script>
<
script
src = "{% static "
shuyucms / js / editable.js
" %}" ></script>
{% endif %}
