{% extends "base.html" %}
{% load i18n %}

{% block meta_title %}{% trans "Home" %}{% endblock %}
{% block title %}{% trans "Home" %}{% endblock %}

{% block breadcrumb_menu %}
<li class="active">{% trans "Home" %}</li>
{% endblock %}

{% block main %}
{% blocktrans %}
<h2>Congratulations!</h2>
<p>
    Welcome to your new shuyucms powered website.
    Here are some quick links to get you started:
</p>
<ul>
    <li><a href="/admin/">Log in to the admin interface</a></li>
    <li><a href="http://shuyucms.jupo.org/docs/content-architecture.html">Creating custom page types</a></li>
    <li><a href="http://shuyucms.jupo.org/docs/frequently-asked-questions.html#templates">Modifying HTML templates</a>
    </li>
    <li>
        <a href="http://shuyucms.jupo.org/docs/frequently-asked-questions.html#why-isn-t-the-homepage-a-page-object-i-can-edit-via-the-admin">Changing
            this homepage</a></li>
    <li><a href="http://shuyucms.jupo.org/docs/frequently-asked-questions.html">Other frequently asked questions</a>
    </li>
    <li><a href="http://shuyucms.jupo.org/docs/configuration.html#default-settings">Full list of settings</a></li>
    <li><a href="http://shuyucms.jupo.org/docs/deployment.html">Deploying to a production server</a></li>
</ul>
{% endblocktrans %}
{% endblock %}
